import { ChatMessageDirection } from './ChatMessageDirection';
import { ChatMessageFile } from './ChatMessageFile';
import { ChatMessageStatus } from './ChatMessageStatus';
import { ChatMessageType } from './ChatMessageType';
interface ChatMessageOptions {
    id?: string;
    direction?: ChatMessageDirection;
    type?: ChatMessageType;
    status?: ChatMessageStatus;
    progress?: number;
    timestamp?: number;
}
/**
 * Instances of this class represents a message of the chat.
 * For more information about how instances of this class can be obtained see
 * {@link Chat#getMessages} or {@link Chat#getPendingMessages}.
 */
export declare class ChatMessage {
    private composer;
    private data;
    private id?;
    private direction;
    private type;
    private status;
    private progress;
    private timestamp?;
    /** @ignore */
    static of(composer: string, data: string, { id, direction, type, status, progress, timestamp, }?: ChatMessageOptions): ChatMessage;
    private constructor();
    /**
     * @ignore
     * Returns a new ChatMessage with the provided values updated.
     */
    with({ data, id, type, status, progress, timestamp, }?: ChatMessageOptions & {
        data?: ChatMessageFile | string;
    }): ChatMessage;
    /**
     * Returns the ID of the message.
     */
    getId(): string | undefined;
    /**
     * Returns the direction of the message.
     */
    getDirection(): ChatMessageDirection;
    /**
     * Returns the type of the message.
     */
    getType(): ChatMessageType;
    /**
    * Returns the address of the composer of the message.
    */
    getComposer(): string;
    /**
     * Returns the data of the message.
     */
    getData(): ChatMessageFile | string;
    /**
     * Returns the timestamp when the message was sent.
     */
    getTimestamp(): number | undefined;
    /**
     * Returns a number between 0 and 100 indicating the percentage of the message
     * that was sent. Note that text messages can only have two values: 0 and 100.
     */
    getProgress(): number;
    /**
     * Returns the current status of the message.
     */
    getStatus(): ChatMessageStatus;
    /**
     * Returns true when the current status of the message is the specified.
     */
    hasStatus(status: ChatMessageStatus): boolean;
}
export {};
