import { MediaTypes } from '../types';
export interface InviteFromDetails {
    contactName: string;
    displayName: string;
    username: string;
}
/**
 * This class allows access to the details of incoming Conference invitation.
 * This class must not be directly instantiated. Instead,
 * instances of this class are obtained by calling the {@link Conference#getInvite}
 */
export declare class ConferenceInvite {
    private id;
    private from;
    private mediaTypes;
    private context;
    private fromDetails;
    /** @ignore */
    constructor(id: string, from: string, mediaTypes: MediaTypes, context: object | undefined, fromDetails: InviteFromDetails);
    /**
     * Obtains the ID of the incoming invitation
     */
    getId(): string;
    /**
     * Obtains the "gateway" of the caller. This can be a user's gateway or pstn number.
     */
    getFrom(): string;
    /**
     * Obtains the mediaTypes for this conference invite.
     * This allow us to guess if we are invited with audio & video, or only with audio and video
     */
    getMediaTypes(): MediaTypes;
    /**
     * Obtains the context for this conference invite.
     * The context is created by the user placing the invite and it will usually contain extra information
     * about the caller
     */
    getContext(): object;
    /**
     * Provides the resolved information of the caller.
     * It returns contactName, displayName and username. If it doesn't exist, it can return the empty field.
     */
    getCallerInfo(): InviteFromDetails;
}
