import { List } from 'immutable';
import { Observable } from 'rxjs';
import { MeetingService } from '../wac-proxy/wac-stack/MeetingService';
import { Meeting } from './Meeting';
import { MeetingParticipant } from './MeetingParticipant';
export interface MeetingUpdateData extends Partial<Pick<Meeting, 'name' | 'validSince' | 'validUntil'>> {
    id: string;
    participants?: Iterable<MeetingParticipant>;
    password?: string;
}
/**
 * ContactManager instance is obtained by calling the {@link Session#getMeetingManager}
 * method of {@link Session} and must not be directly instantiated.
 */
export declare class MeetingManager {
    private initLock;
    private meetingService;
    private meetingsSubject;
    private meetings$;
    /** @ignore */
    constructor(meetingService: MeetingService);
    /** @ignore */
    init(): Promise<void>;
    /** @ignore */
    uninit(): Promise<void>;
    /**
     * Retrieves a list with the available meetings
     */
    getMeetings$(): Observable<List<Meeting>>;
    /**
     * Retrieves a meeting with the following id
     * @param meetingId Id of the meeeting to retrieve
     */
    getMeeting(meetingId: string): Promise<Meeting>;
    /**
     * Creates a meeting
     * @param name The name of the meeting.
     * @param participants The participants of the new meeting session.
     * @param validSince The timestamp of the moment when the meeting starts.
     * @param validUntil The timestamp until the meeting is valid.
     * @param sendSms If true, an invitation for the meeting will be sent in an SMS by the server.
     * @param password Password for meeting access protection
     * @return The just created meeting
     */
    createMeeting(name: string, participants: Iterable<MeetingParticipant>, validSince: number, validUntil?: number, sendSms?: boolean, password?: string): Promise<Meeting>;
    /**
     * Updates a meeting
     * @param meeting
     * @param sendSms Flag used to decide whether to send an SMS message or not
     */
    saveMeeting(meeting: MeetingUpdateData, sendSms?: boolean): Promise<Meeting>;
    /**
     * Removes a meeting given its id
     * @param meeting
     * @param meeting.id
     */
    removeMeeting({ id }: Pick<Meeting, 'id'>): Promise<void>;
    private onMeeting;
    private onMeetingDelete;
    private notifyMeeting;
}
