import { EventEmitter2 } from 'eventemitter2';
/**
 * Like an EventEmitter, instances of this class allow us
 * register and unregister listeners for events, but it allows listening
 * for those messages that match a pattern.
 *
 * @example
 *   let x = new Emitter();
 *   x.addContentListener({foo: 'bar'}, (data) => {
 *     console.log('received data', data);
 *   });
 *   x.emit({foo: 'bar', hello: 'world'})
 *
 *   > received data {foo: 'bar', hello: 'world'}
 */
export declare class Emitter extends EventEmitter2 {
    private contentListeners;
    /**
     * Add an event listener that will be called when an event that matches
     * provided filter is received
     * @param filter filter that should match emited events to call provided function
     * @param fn callback to invoke on each new match.
     */
    addContentListener(filter: {
        request: string;
        payload: any;
    }, fn: () => void): void;
    /**
     * Stop receiving events on a previously added listener.
     * @param fn callback to remove from listeners list.
     */
    removeContentListener(fn: () => void): void;
    emit(event: string[] | string, ...values: any[]): boolean;
    /**
     * Check if given data matches provided filter.
     * @param {object} item tested element.
     * @param {object} filter tested filter.
     * @return {boolean} true if item matches filter.
     */
    private match;
}
